#!/bin/sh

# Copyright (C) 2023-2024 Internet Systems Consortium, Inc. ("ISC")
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# shellcheck disable=SC1091
# SC1091: Not following: ... was not specified as input (see shellcheck -x).

# Exit with error if commands exit with non-zero and if undefined variables are
# used.
set -eu

# shellcheck disable=SC2034
# SC2034: ... appears unused. Verify use (or export if used externally).
prefix="/usr"

# Include utilities. Use installed version if available and
# use build version if it isn't.
if test -f "${prefix}/share/kea/scripts/admin-utils.sh"; then
    . "${prefix}/share/kea/scripts/admin-utils.sh"
else
    . "/home/ubuntu/workspace/kea-dev/pkg/kea-src/kea-2.5.5/obj-x86_64-linux-gnu/src/bin/admin/admin-utils.sh"
fi

VERSION=$(pgsql_version "$@")

if [ "$VERSION" != "19.0" ]; then
    printf 'This script upgrades 19.0 to 20.0. '
    printf 'Reported version is %s. Skipping upgrade.\n' "${VERSION}"
    exit 0
fi

psql "$@" >/dev/null <<EOF
START TRANSACTION;

-- This line starts the schema upgrade to version 20.0.

-- Add subnet id and address index for lease6.
CREATE INDEX lease6_by_subnet_id_address ON lease6 (subnet_id, address ASC);

-- Update the schema version number.
UPDATE schema_version
    SET version = '20', minor = '0';

-- This line concludes the schema upgrade to version 20.0.

-- Commit the script transaction.
COMMIT;

EOF
